#ifndef _BCRCTL_H_
#define _BCRCTL_H_

/*==========================================================================  		
Description: 
            
        System controls of hand-held terminal   
              
Histroy:       
        
        1.Version:1.0.0  Date: 2008/05/13 
            
          First Release 
           
        2.Version:1.0.1  Date: 2008/09/24  
                      
          Add SysGetLibraryVersion function
        
        3.Version:1.0.2  Date: 2008/11/06  
                      
          Add below functions
          
          a. BCRSetVibratorState / BCRGetVibratorState    
          
          b. BCRSetOutputMode / BCRGetOutputMode 
          
          c. BCRSetTriggerKey / BCRGetTriggerKey  
          
          d. BCRSetScanAngle / BCRGetScanAngle    
          
          e. BCRTriggerPress / BCRTriggerRelease
                                   	            
=============================================================================*/


#ifdef __cplusplus
    #define BCRLIB extern "C"	
#else
    #define BCRLIB extern
#endif 

typedef struct _BCR_READABLE_BARCODE_
{	
DWORD dwSize;  //Specifies the structure length, in bytes

DWORD dwValidFileds;//Specifies the number of readable codes.

//bits 0~7 	
DWORD BCR_UPC:1;                        
DWORD BCR_UPC_2:1;                      
DWORD BCR_UPC_5:1;                      
DWORD BCR_EAN:1;                        
DWORD BCR_EAN_2:1;                                      
DWORD BCR_EAN_5:1;                      
DWORD BCR_CODE39:1;                    
DWORD BCR_TRIOPTIC:1;  

//bits 8~15         
DWORD BCR_CODABAR:1;                    
DWORD BCR_INDUSTRIAL_2of5:1;            
DWORD BCR_INTERLEAVED_2of5:1;           
DWORD BCR_SCODE:1;                        
DWORD BCR_MATRIX_2of5:1;                
DWORD BCR_CHINPOST:1;   
DWORD BCR_KOREAN_POSTAL_AUTHORITY:1;
DWORD BCR_IATA:1; 

 //bits 16~23                        
DWORD BCR_MSI_PLESSEY:1;                
DWORD BCR_TELEPEN:1;                    
DWORD BCR_UK_PLESSEY:1;                 
DWORD BCR_CODE128:1;                     
DWORD BCR_CODE93:1;                    
DWORD BCR_CODE11:1;                    
DWORD BCR_RSS_14:1;                     
DWORD BCR_RSS_LIMITED:1;   
  
//bits 24~31               
DWORD BCR_RSS_EXPANDED:1;               
DWORD BCR_DATAMATRIX_ECC000:1;         
DWORD BCR_DATAMATRIX_ECC200:1;         
DWORD BCR_AZTEC:1;                    
DWORD BCR_AZTEC_RUNES:1;                
DWORD BCR_QR_CODE:1;                    
DWORD BCR_MAXICODE:1;                   
DWORD BCR_PDF417:1; 

//bits 32                      
DWORD BCR_MICRO_PDF417:1;             
             
} BCR_READABLE_BARCODE, *LPBCR_READABLE_BARCODE;


//MAX buffer size
#define BCR_MAX_PATH    260  
   
#define BCR_TRIGGER_ENABLE   (TRUE)

#define BCR_TRIGGER_DISABLE  (FALSE)


//Settings of buzzer volume
#define BCR_BUZZER_MUTE            0

#define BCR_BUZZER_VOLUME_LOW      1

#define BCR_BUZZER_VOLUME_MIDDLE   2

#define BCR_BUZZER_VOLUME_HIGH     3


//Settings of read mode
#define BCR_READMODE_SINGLE        0

#define BCR_READMODE_MULTIPLE      1


//Settings of read time
#define BCR_READ_INDEFINITELY      0xff


//Settings of output mode
#define BCR_OUTPUT_MODE_BUFFER     0x01

#define BCR_OUTPUT_MODE_KEYCODE    (0x01<<1)

#define BCR_OUTPUT_MODE_CLIPBOARD  (0x01<<2)


//Settings of scan angle
#define BCR_SCANANGLE_NORMAL        0

#define BCR_SCANANGLE_NARROW        1


//Windows message for BCR
#define WM_BCR_SCAN_NOTIFY    (WM_APP + 101)

//status of scan process
#define BCR_READ_NOT_READY  1 

#define BCR_READ_GOOD       2 

#define BCR_READ_NO_DATA    3

#define BCR_READ_TIMEOUT    4

#define BCR_READ_DISABLED   5

#define BCR_READ_ABORT      6


//=====================================
//=         General Settings          =
//=====================================
typedef BOOL (*PFN_BCRGetPowerStatus)(PBOOL pbPowerStatus);	
  
typedef BOOL (*PFN_BCRPowerOn) (void);
	
typedef BOOL (*PFN_BCRPowerOff)(void);

typedef BOOL (*PFN_BCREnableTriggerKey) (void);
	
typedef BOOL (*PFN_BCRDisableTriggerKey)(void);

typedef BOOL (*PFN_BCRGetTriggerKeyStatus)(PBOOL lpdwTriggerKeyState);

typedef BOOL (*PFN_BCRSetBuzzerStatus)  (DWORD dwBuzzerVolume,LPCTSTR lpBeepFile);
	
typedef BOOL (*PFN_BCRGetBuzzerStatus)  (LPDWORD lpdwBuzzerVolume,LPCTSTR lpBeepFile);

typedef BOOL (*PFN_BCRGetKbdEmulatorMode)  (PBOOL pbKbdEmulatorMode,PBYTE pAdditionalVk);

typedef BOOL (*PFN_BCRSetKbdEmulatorMode)  (BOOL bKbdEmulatorMode,BYTE AdditionalVk);

typedef BOOL (*PFN_BCRSetOutputMode)    (DWORD dwOutputMode);

typedef BOOL (*PFN_BCRGetOutputMode)    (LPDWORD lpOutputMode);

typedef BOOL (*PFN_BCRSetVibratorState) (DWORD dwVibratorTime);

typedef BOOL (*PFN_BCRGetVibratorState) (LPDWORD lpVibratorTime);

typedef BOOL (*PFN_BCRGetSettings)(PBYTE pSettingsData);

typedef BOOL (*PFN_BCRSetSettings)(PBYTE pSettingsData);

BCRLIB BOOL BCRGetPowerStatus(PBOOL pbPowerStatus);

BCRLIB BOOL BCRPowerOn(void);

BCRLIB BOOL BCRPowerOff(void);

BCRLIB BOOL BCREnableTriggerKey(void);

BCRLIB BOOL BCRDisableTriggerKey(void);

BCRLIB BOOL BCRGetTriggerKeyStatus(PBOOL lpdwTriggerKeyState);

BCRLIB BOOL BCRSetBuzzerStatus(DWORD dwBuzzerVolume,LPCTSTR lpBeepFile);

BCRLIB BOOL BCRGetBuzzerStatus(LPDWORD lpdwBuzzerVolume,LPCTSTR lpBeepFile);

BCRLIB BOOL BCRGetKbdEmulatorMode  (PBOOL pbKbdEmulatorMode,PBYTE pAdditionalVk);

BCRLIB BOOL BCRSetKbdEmulatorMode  (BOOL bKbdEmulatorMode,BYTE AdditionalVk);

BCRLIB BOOL BCRSetOutputMode(DWORD dwOutputMode);

BCRLIB BOOL BCRGetOutputMode(LPDWORD lpOutputMode);

BCRLIB BOOL BCRGetSettings(PBYTE pSettingsData);

BCRLIB BOOL BCRSetSettings(PBYTE pSettingsData);

//=====================================
//=         Decoder Options           =
//=====================================

typedef BOOL (*PFN_BCRSetReadableCode)(BCR_READABLE_BARCODE BCRSymbology);	

typedef BOOL (*PFN_BCRGetReadableCode)(LPBCR_READABLE_BARCODE lpBCRSymbology);	

typedef BOOL (*PFN_BCRSetReadMode)(DWORD dwReadMode);	

typedef BOOL (*PFN_BCRGetReadMode)(LPDWORD lpdwReadMode);	

typedef BOOL (*PFN_BCRSetReadTimeOption)(DWORD dwReadTime);	

typedef BOOL (*PFN_BCRGetReadTimeOption)(LPDWORD lpdwReadTime);	

typedef BOOL (*PFN_BCRSetDecoderDefault)(void);	

typedef BOOL (*PFN_BCRSendCommand)(LPTSTR lpOptionsString);	

typedef BOOL (*PFN_BCRSetScanAngle)(DWORD dwScanAngle);	

typedef BOOL (*PFN_BCRGetScanAngle)(LPDWORD lpScanAngle);	


BCRLIB BOOL BCRSetReadableCode(BCR_READABLE_BARCODE BCRSymbology);

BCRLIB BOOL BCRGetReadableCode(LPBCR_READABLE_BARCODE lpBCRSymbology);

BCRLIB BOOL BCRSetReadMode(DWORD dwReadMode);

BCRLIB BOOL BCRGetReadMode(LPDWORD lpdwReadMode);

BCRLIB BOOL BCRSetReadTimeOption(DWORD dwReadTime);

BCRLIB BOOL BCRGetReadTimeOption(LPDWORD lpdwReadTime);

BCRLIB BOOL BCRSetDecoderDefault(void);

BCRLIB BOOL BCRSendCommand(LPTSTR lpOptionsString);

BCRLIB BOOL BCRSetScanAngle(DWORD dwScanAngle);

BCRLIB BOOL BCRGetScanAngle(LPDWORD lpScanAngle);

//=====================================
//=        Barcode Reading            =
//=====================================

typedef BOOL (*PFN_BCRStartScan) (void);

typedef BOOL (*PFN_BCRAbortScan) (void);	


typedef BOOL (*PFN_BCRGetBarcode)(BYTE* pDecodeData,LPDWORD lpdwLength,LPDWORD lpFlag);

BCRLIB BOOL BCRStartScan(void);

BCRLIB BOOL BCRAbortScan(void);

BCRLIB BOOL BCRGetBarcode(BYTE* pDecodeData,LPDWORD lpdwLength,LPDWORD lpFlag); 


//=====================================
//=        Notification            =
//=====================================
typedef BOOL (*PFN_GetReadNotification)(UINT *pReadDataMsg,LPTSTR lpReadDataEventName);

typedef BOOL (*PFN_BCRGetLastReadEventStatus)(LPDWORD lpdwStatus);

BCRLIB BOOL BCRGetReadNotification(UINT *pReadDataMsg,LPTSTR lpReadDataEventName);

BCRLIB BOOL BCRGetLastReadEventStatus(LPDWORD lpdwStatus);

//=====================================
//=        Information                =
//=====================================
typedef BOOL (*PFN_BCRGetFirmwareVersion)(LPTSTR lpFirmwareVersion);

typedef BOOL (*PFN_BCRGetDriverVersion)(LPTSTR lpDriverVersion);

typedef BOOL (*PFN_BCRGetLibraryVersion) (LPTSTR lpLibraryVersion);

BCRLIB BOOL BCRGetFirmwareVersion(LPTSTR lpFirmwareVersion);

BCRLIB BOOL BCRGetDriverVersion(LPTSTR lpDriverVersion);

BCRLIB BOOL BCRGetLibraryVersion(LPTSTR lpLibraryVersion);


typedef BOOL (*PFN_ReloadCMDCheckedForPowerOn)(void);

BCRLIB BOOL BCRReloadCMDCheckedForPowerOn(void);

#endif 